@@ -14,20 +14,24 @@
 use std::borrow::Cow;
 
 use serde::{Deserialize as De, Serialize as Ser};
+#[cfg(feature = "validation")]
 use validator::Validate;
 
+#[cfg(feature = "validation")]
+use crate::val_helpr::*;
 use crate::{compose::{opt::{AnyText, NoUrl},
                       Confirm,
                       Opt},
-            text,
-            val_helpr::*};
+            text};
 
 type MyOpt<'a> = Opt<'a, AnyText, NoUrl>;
 
+#[cfg(feature = "validation")]
 fn validate_options<'a>(o: &Cow<'a, [MyOpt<'a>]>) -> ValidatorResult {
   below_len("Checkboxes.options", 10, o.as_ref())
 }
 
+#[cfg(feature = "validation")]
 fn validate_initial_options<'a>(o: &Cow<'a, [MyOpt<'a>]>) -> ValidatorResult {
   below_len("Checkboxes.initial_options", 10, o.as_ref())
 }
@@ -44,19 +48,21 @@ fn validate_initial_options<'a>(o: &Cow<'a, [MyOpt<'a>]>) -> ValidatorResult {
 /// [slack api docs 🔗]: https://api.slack.com/reference/block-kit/block-elements#checkboxes
 /// [blocks 🔗]: https://api.slack.com/reference/block-kit/blocks
 /// [app surfaces 🔗]: https://api.slack.com/surfaces
-#[derive(Clone, Debug, Hash, PartialEq, Ser, De, Validate)]
+#[derive(Clone, Debug, Hash, PartialEq, Ser, De)]
+#[cfg_attr(feature = "validation", derive(Validate))]
 pub struct Checkboxes<'a> {
-  #[validate(length(max = 255))]
+  #[cfg_attr(feature = "validation", validate(length(max = 255)))]
   action_id: Cow<'a, str>,
 
-  #[validate(custom = "validate_options")]
+  #[cfg_attr(feature = "validation", validate(custom = "validate_options"))]
   options: Cow<'a, [MyOpt<'a>]>,
 
-  #[validate(custom = "validate_initial_options")]
+  #[cfg_attr(feature = "validation",
+             validate(custom = "validate_initial_options"))]
   #[serde(skip_serializing_if = "Option::is_none")]
   initial_options: Option<Cow<'a, [MyOpt<'a>]>>,
 
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   #[serde(skip_serializing_if = "Option::is_none")]
   confirm: Option<Confirm>,
 }
@@ -100,6 +106,8 @@ impl<'a> Checkboxes<'a> {
   ///
   /// assert!(matches!(input.validate(), Err(_)))
   /// ```
+  #[cfg(feature = "validation")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "validation")))]
   pub fn validate(&self) -> ValidationResult {
     Validate::validate(self)
   }
