@@ -14,13 +14,15 @@
 use std::borrow::Cow;
 
 use serde::{Deserialize as De, Serialize as Ser};
+#[cfg(feature = "validation")]
 use validator::Validate;
 
+#[cfg(feature = "validation")]
+use crate::val_helpr::ValidationResult;
 use crate::{compose::{opt::{AnyText, NoUrl},
                       Confirm,
                       Opt},
-            text,
-            val_helpr::ValidationResult};
+            text};
 
 /// Opt state supported by radio buttons
 pub type RadioButtonOpt<'a> = Opt<'a, AnyText, NoUrl>;
@@ -37,21 +39,22 @@ pub type RadioButtonOpt<'a> = Opt<'a, AnyText, NoUrl>;
 /// [slack api docs 🔗]: https://api.slack.com/reference/block-kit/block-elements#radio
 /// [blocks 🔗]: https://api.slack.com/reference/block-kit/blocks
 /// [app surfaces 🔗]: https://api.slack.com/surfaces
-#[derive(Clone, Debug, Hash, PartialEq, Ser, De, Validate)]
+#[derive(Clone, Debug, Hash, PartialEq, Ser, De)]
+#[cfg_attr(feature = "validation", derive(Validate))]
 pub struct Radio<'a> {
-  #[validate(length(max = 255))]
+  #[cfg_attr(feature = "validation", validate(length(max = 255)))]
   action_id: Cow<'a, str>, // max 255
 
-  #[validate(length(max = 10))]
-  #[validate]
+  #[cfg_attr(feature = "validation", validate(length(max = 10)))]
+  #[cfg_attr(feature = "validation", validate)]
   options: Vec<RadioButtonOpt<'a>>, // max 10, plain or md
 
   #[serde(skip_serializing_if = "Option::is_none")]
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   initial_option: Option<RadioButtonOpt<'a>>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   confirm: Option<Confirm>,
 }
 
@@ -92,6 +95,8 @@ impl<'a> Radio<'a> {
   ///
   /// assert!(matches!(input.validate(), Err(_)))
   /// ```
+  #[cfg(feature = "validation")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "validation")))]
   pub fn validate(&self) -> ValidationResult {
     Validate::validate(self)
   }
